import Vue from 'vue';
import VueI18n from 'vue-i18n';
Vue.use(VueI18n);

const messages = {
    'en': {
        Login: {
            loginHeader: 'Login',
            registerBtn: 'Register',
            username: 'username',
            password: 'password',
            loginBtn: 'login',
            passwordHint: 'At Least 8 characters',
            required: 'Required',
            min8Character: 'Min 8 Characters',
            usernameAlert: 'please enter username',
            passwordAlert: 'please enter password',
            errorUserNotFound: 'User not found',
            errorIncorrectPassword: 'Incorrect Password',
            changePassword: 'Change Password?'
        },
        Register: {
            registerHeader: 'Register',
            loginBtn: 'login',
            username: 'username',
            password: 'password',
            repeatPassword: 'repeat password',
            registerBtn: 'Register And Login',
            required: 'Required',
            min8Character: 'Min 8 Characters',
            matchPass: "password and repeat passwords must be the same",
            usernameAlert: 'please enter username',
            firstPassAlert: 'please enter password',
            secondPassAlert: 'please enter password',
            error403: 'Username already exists',
            loadingText: 'creating user',
            userCreated: 'user has been Created'
        },
        AppHeader: {
            appName: 'Karname',
        },
        AppFooter: {
            appLang: 'en',
        },
        ChangePassword: {
            formHeader: 'change password',
            username: 'username',
            usernameAlert: 'please enter username',
            oldPassword: 'old password',
            oldPasswordAlert: 'please enter old password',
            newPassword: 'new password',
            newPasswordAlert: 'please enter new password',
            matchPass: 'old password and new password should not be the same',
            required: 'Required',
            min8Character: 'Min 8 Characters',
            changePasswordBtn: 'change',
            loadingText: 'changing password',
            NotFoundUser: 'user not found',
            CheckPassError: 'incorrect old password',
            SuccessChangePass: 'Password Successfully changed',
            internalServerError: 'internal server error'
        },
        WorkList: {
            deviceComboboxLabel: 'please select a device',
            deviceComboboxNoDataMatch: 'No results matching',
            editBtn: 'edit',
            deviceComboboxNoDataMatch1: '',
            AllBtn: "All",
            UnknownBtn: "Correction Needed",
            noDevicemap: 'no device',
            Register: "Register",
            CreatePatient: "Create",
            RegisterPatient: "Register Patient",
            EditRegisterPatient: "Edit Patient Information",
            FarsiFirstName: "Farsi First Name",
            EnglishFirstName: "English First Name",
            FarsiLastName: "Farsi Last Name",
            EnglishLastName: "English Last Name"
        },
        HISLink: {
            DeleteMessage: "Are You Sure?",
            YesBtn: "yes",
            NoBtn: "no",
            newText: "New",
            editText: "Edit",
            HISLinkName: "HISLink",
            createBtn: "Create",
            newBtn: "New",
            editBtn: "Edit",
            deleteBtn: "Delete",
            activeBtn: "Active",
            deactiveBtn: "Deactive",
            authenticateBtn: "Authenticate",
            getWorklistBtn: "Worklist",
            hislinkSelectStatement: "please select one of hislinks",
            hislinkDeleteStatement: "HisLink has been deleted",
            hislinkActiveStatement: "HisLink has been activated",
            hislinkDeactiveStatement: "HisLink has been deactivated",
            hislinkAuthenticateFailed: "authenticate failed",
            hislinkAuthenticateSuccess: "authenticate success",
            hislinkRelationshipError: "selected HisLink have been linked to a devicemap"
        },
        Client: {
            DeleteMessage: "Are You Sure?",
            YesBtn: "yes",
            NoBtn: "no",
            newText: "New",
            editText: "Edit",
            clientName: "Client",
            createBtn: "Create",
            editBtn: "Edit",
            clientSelectStatement: "please select one of Clients",
            clientDeleteStatement: "Client has been deleted",
            clientRelationshipError: "selected Client have been linked to a devicemap"
        },
        DeviceMap: {
            DeleteMessage: "Are You Sure?",
            YesBtn: "yes",
            NoBtn: "no",
            newText: "New",
            editText: "Edit",
            devicemapName: "DeviceMap",
            createBtn: "Create",
            editBtn: "Edit",
            devicemapSelectStatement: "please select one of DeviceMaps",
            devicemapDeleteStatement: "Devicemap has been deleted",
        },
        Users: {
            DeleteMessage: "Are You Sure?",
            YesBtn: "yes",
            NoBtn: "no",
            newText: "New",
            editText: "Edit",
            UserName: "Users",
            createBtn: "Create",
            resetPassword: "Reset Password",
            editBtn: "Edit",
            userSelectStatement: "please select one of users",
            userDeleteStatement: "user has been deleted",
            UsernameTxtBox: "Username",
            FullNameTxtBox: "Fullname",
            ResetPasswordBtn: "Reset Password",
            matchPassword: "password and its repeat must be the same",
            minimum5Character: "minimum 5 characters required"

        },
        HisWorklist: {
            title: "Worklist"
        },
        UserSetting: {
            language: "Language",
            fullName: "Full Name",
            SaveBtn: "Save",
            chooseLanguage: "please choose a language",
            successfullSave: "changes have been successfully saved",
            chooseImage: "please choose an image"
        },
        NavigationBar: {
            Worklist: "Worklist",
            HISLink: "HISLink",
            DeviceMap: "DeviceMap",
            Client: "Client",
            Users: "Users",
            Setting: "Setting",
            Signout: "Signout",
            Register: "Register",
            Transliteration: "Transliteration"
        },
        RegisterRoute: {
            HISLinkCombo: "HISLink",
            searchBtn: "Search",
            advancedSearchLabel: "Advanced search",
            jsonParseError: "error in parse of given json",
            dbError: "error in query, please edit query"
        },
        TransliterationRoute: {
            uploadLabel: "Upload DB",
            uploadingText: "Uploading...",
            errorInUploading: "Error In Uploading",
            wrongFormat: "Wrong Format",
            finishUpload: "Upload finished",
            dbUpdate: "updating db",
            dbUpdateDone: "db updating have been done"

        },
        DataTableSearch: "search"

    },
    'fa': {
        Login: {
            loginHeader: 'ورود کاربر',
            registerBtn: 'ثبت نام',
            username: 'شناسه کاربری',
            password: 'رمز ورود',
            loginBtn: 'ورود',
            passwordHint: 'حداقل 8 کاراکتر',
            required: 'مورد نیاز',
            min8Character: 'حداقل 8 کاراکتر',
            usernameAlert: 'لطفا شناسه کاربری را وارد نمایید',
            passwordAlert: 'لطفا رمز ورود را وارد نمایید',
            errorUserNotFound: 'کاربر یافت نشد',
            errorIncorrectPassword: 'رمز نادرست',
            changePassword: 'تغییر رمز؟'
        },
        Register: {
            registerHeader: 'ثبت نام کاربر',
            loginBtn: 'ورود',
            username: 'شناسه کاربری',
            password: 'رمز ورود',
            repeatPassword: 'تکرار رمز ورود',
            registerBtn: 'ثبت نام و ورود',
            required: 'مورد نیاز',
            min8Character: 'حداقل 8 کاراکتر',
            matchPass: "رمز عبور و تکرار آن باید مشابه باشند",
            usernameAlert: 'لطفا شناسه کاربری را وارد نمایید',
            firstPassAlert: 'لطفا رمز را وارد نمایید',
            secondPassAlert: 'لطفا رمز را وارد نمایید',
            error403: 'شناسه کاربری وجود دارد',
            loadingText: 'در حال ایجاد کاربر',
            userCreated: 'کاربر ایجاد شد'
        },
        AppHeader: {
            appName: 'کارنامه',
        },
        AppFooter: {
            appLang: 'فا',
        },
        ChangePassword: {
            formHeader: 'تغییر رمز',
            username: 'شناسه کاربری',
            usernameAlert: 'لطفا شناسه کاربری را وارد نمایید',
            oldPassword: 'رمز فعلی',
            oldPasswordAlert: 'لطفا رمز فعلی را وارد نمایید',
            newPassword: 'رمز جدید',
            newPasswordAlert: 'لطفا رمز جدید را وارد نمایید',
            matchPass: 'رمز فعلی و رمز جدید نباید یکسان باشند',
            required: 'مورد نیاز',
            min8Character: 'حداقل 8 کاراکتر',
            changePasswordBtn: 'تغییر رمز',
            loadingText: 'در حال تغییر رمز',
            NotFoundUser: 'کاربر یافت نشد',
            CheckPassError: 'رمز فعلی نادرست می باشد',
            SuccessChangePass: 'رمز کاربر با موفقیت تغییر یافت',
            internalServerError: 'خطا در سرور'
        },
        WorkList: {
            deviceComboboxLabel: 'لطفا یک دستگاه را انتخاب نمایید',
            deviceComboboxNoDataMatch: 'هیچ نتیجه ای برابر با',
            editBtn: 'ویرایش',
            deviceComboboxNoDataMatch1: 'یافت نشد',
            AllBtn: "همه",
            UnknownBtn: "نیازمند اصلاح",
            noDevicemap: 'دستگاه انتخاب نشده است',
            Register: "ثبت",
            CreatePatient: "ایجاد",
            RegisterPatient: "ایجاد بیمار",
            EditRegisterPatient: "ویرایش اطلاعات بیمار",
            FarsiFirstName: "نام به فارسی",
            EnglishFirstName: "نام به انگلیسی",
            FarsiLastName: "نام خانوادگی به فارسی",
            EnglishLastName: "نام خانوادگی به انگلیسی"
        },

        HISLink: {
            DeleteMessage: "آیا مطمین هستید؟",
            YesBtn: "بله",
            NoBtn: "نه",
            newText: "جدید",
            editText: "ویرایش",
            HISLinkName: "HISLink",
            createBtn: "ایجاد",
            newBtn: "جدید",
            editBtn: "ویرایش",
            deleteBtn: "حذف",
            activeBtn: "فعال",
            deactiveBtn: "غیرفعال",
            authenticateBtn: "تصدیق کردن",
            getWorklistBtn: "فهرست",
            hislinkSelectStatement: "لطفا یکی از hislink ها را انتخاب نمایید",
            hislinkDeleteStatement: "HISLink حذف گردید",
            hislinkActiveStatement: "HISLink فعال شد",
            hislinkDeactiveStatement: "HISLink غیرفعال شد",
            hislinkAuthenticateFailed: "authenticate failed",
            hislinkAuthenticateSuccess: "authenticate success",
            hislinkRelationshipError: "درگاه انتخاب شده دارای یک  نگاشت می باشد"
        },
        Client: {
            DeleteMessage: "آیا مطمین هستید؟",
            YesBtn: "بله",
            NoBtn: "نه",
            newText: "جدید",
            editText: "ویرایش",
            clientName: "Client",
            createBtn: "ایجاد",
            editBtn: "ویرایش",
            clientSelectStatement: "لطفا یکی از Client ها را انتخاب نمایید",
            clientDeleteStatement: "Client حذف گردید",
            clientRelationshipError: "دستگاه انتخاب شده دارای یک  نگاشت می باشد"
        },
        DeviceMap: {
            DeleteMessage: "آیا مطمین هستید؟",
            YesBtn: "بله",
            NoBtn: "نه",
            newText: "جدید",
            editText: "ویرایش",
            devicemapName: "DeviceMap",
            createBtn: "ایجاد",
            editBtn: "ویرایش",
            devicemapSelectStatement: "لطفا یکی از DeviceMap ها را انتخاب نمایید",
            devicemapDeleteStatement: "DeviceMap حذف گردید",
        },
        Users: {
            DeleteMessage: "آیا مطمین هستید؟",
            YesBtn: "بله",
            NoBtn: "نه",
            newText: "جدید",
            editText: "ویرایش",
            resetPassword: "تغییر رمز کاربر",
            UserName: "کاربر",
            createBtn: "ایجاد",
            editBtn: "ویرایش",
            userSelectStatement: "لطفا یکی از کاربر ها را انتخاب نمایید",
            userDeleteStatement: "کاربر حذف گردید",
            UsernameTxtBox: "شناسه کاربری",
            FullNameTxtBox: "نام و نام خانوادگی",
            ResetPasswordBtn: "تغییر رمز",
            matchPassword: "رمز و تکرار آن می بایست یکی باشد",
            minimum5Character: "رمز باید حداقل دارای 5 کاراکتر باشد"
        },
        HisWorklist: {
            title: "فهرست"
        },
        UserSetting: {
            language: "زبان",
            fullName: "نام خانوادگی",
            SaveBtn: "ذخیره",
            chooseLanguage: "لطفا یک زبان را انتخاب نمایید",
            successfullSave: "اطلاعات با موفقیت ذخیره گردید",
            chooseImage: "لطفا یک عکس انتخاب نمایید"
        },
        NavigationBar: {
            Worklist: "لیست کاری",
            HISLink: "درگاه HIS",
            DeviceMap: "نگاشت",
            Client: "دستگاه",
            Users: "کاربران",
            Setting: "تنظیمات",
            Signout: "خروج",
            Register: "فهرست",
            Transliteration: "نویسه"
        },
        RegisterRoute: {
            HISLinkCombo: "درگاه HIS",
            searchBtn: "جستجو",
            advancedSearchLabel: "جستجوی پیشرفته",
            jsonParseError: "خطا در Parse عبارت وارد شده",
            dbError: "خطا در query، لطفا query را اصلاح نمایید"
        },
        TransliterationRoute: {
            uploadLabel: "بارگزاری دیتابیس",
            uploadingText: "در حال بارگزاری...",
            errorInUploading: "خطا در بارگزاری",
            wrongFormat: "فرمت اشتباه",
            finishUpload: "بارگذاری به اتمام رسید",
            dbUpdate: "در حال بروزرسانی دیتابیس",
            dbUpdateDone: "بروزرسانی دیتابیس به اتمام رسید"
        },
        DataTableSearch: "جستجو"

    }
};

const i18n = new VueI18n({
    locale: 'en', // set locale    
    fallbackLocale: 'fa', // set fallback locale    
    messages, // set locale messages
});

export default i18n;